@@ -1,24 +1,28 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for cloudwatch service ServiceResource
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudwatch import CloudWatchServiceResource
-    import mypy_boto3.cloudwatch.service_resource as cloudwatch_resources
+
+    from mypy_boto3_cloudwatch import CloudWatchServiceResource
+    import mypy_boto3_cloudwatch.service_resource as cloudwatch_resources
 
     resource: CloudWatchServiceResource = boto3.resource("cloudwatch")
-    session_resource: CloudWatchServiceResource = session.resource("cloudwatch")
 
-    Alarm: cloudwatch_resources.Alarm = resource.Alarm(...)
-    ...
+    my_alarm: cloudwatch_resources.Alarm = resource.Alarm(...)
+    my_metric: cloudwatch_resources.Metric = resource.Metric(...)
+```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Generator, Iterator, List, TYPE_CHECKING, TypeVar
+from datetime import datetime
+from typing import Any, Iterator, List
+
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
+
 from mypy_boto3_cloudwatch.type_defs import (
     DescribeAlarmHistoryOutputTypeDef,
     DimensionFilterTypeDef,
@@ -47,13 +51,13 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     """
 
     def all(self) -> "ServiceResourceAlarmsCollection":
         pass
 
-    def filter(
+    def filter(  # type: ignore
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
@@ -82,7 +86,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
     def page_size(self, count: int) -> "ServiceResourceAlarmsCollection":
         pass
 
-    def pages(self) -> Generator[List["Alarm"], None, None]:
+    def pages(self) -> Iterator[List["Alarm"]]:
         pass
 
     def __iter__(self) -> Iterator["Alarm"]:
@@ -91,13 +95,13 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     """
 
     def all(self) -> "ServiceResourceMetricsCollection":
         pass
 
-    def filter(
+    def filter(  # type: ignore
         self,
         Namespace: str = None,
         MetricName: str = None,
@@ -112,7 +116,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
     def page_size(self, count: int) -> "ServiceResourceMetricsCollection":
         pass
 
-    def pages(self) -> Generator[List["Metric"], None, None]:
+    def pages(self) -> Iterator[List["Metric"]]:
         pass
 
     def __iter__(self) -> Iterator["Metric"]:
@@ -121,17 +125,17 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     """
 
     def all(self) -> "MetricAlarmsCollection":
         pass
 
-    def filter(
+    def filter(  # type: ignore
         self,
         Statistic: Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"] = None,
         ExtendedStatistic: str = None,
-        Dimensions: List[DimensionTypeDef] = None,
+        Dimensions: List["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: Literal[
             "Seconds",
@@ -180,7 +184,7 @@ class MetricAlarmsCollection(ResourceCollection):
     def page_size(self, count: int) -> "MetricAlarmsCollection":
         pass
 
-    def pages(self) -> Generator[List["Alarm"], None, None]:
+    def pages(self) -> Iterator[List["Alarm"]]:
         pass
 
     def __iter__(self) -> Iterator["Alarm"]:
@@ -189,7 +193,7 @@ class MetricAlarmsCollection(ResourceCollection):
 
 class Alarm(Boto3ServiceResource):
     """
-    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     """
 
     alarm_name: str
@@ -220,10 +224,11 @@ class Alarm(Boto3ServiceResource):
     metrics: List[Any]
     threshold_metric_id: str
     name: str
+    metric: "Metric"
 
     def delete(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         """
 
     def describe_history(
@@ -237,32 +242,32 @@ class Alarm(Boto3ServiceResource):
         ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         """
 
     def disable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         """
 
     def enable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         """
 
     def load(self) -> None:
         """
-        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         """
 
     def reload(self) -> None:
         """
-        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         """
 
     def set_state(
@@ -272,7 +277,7 @@ class Alarm(Boto3ServiceResource):
         StateReasonData: str = None,
     ) -> None:
         """
-        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         """
 
 
@@ -281,7 +286,7 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     """
 
     metric_name: str
@@ -292,7 +297,7 @@ class Metric(Boto3ServiceResource):
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         """
 
     def get_statistics(
@@ -300,7 +305,7 @@ class Metric(Boto3ServiceResource):
         StartTime: datetime,
         EndTime: datetime,
         Period: int,
-        Dimensions: List[DimensionTypeDef] = None,
+        Dimensions: List["DimensionTypeDef"] = None,
         Statistics: List[Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"]] = None,
         ExtendedStatistics: List[str] = None,
         Unit: Literal[
@@ -334,12 +339,12 @@ class Metric(Boto3ServiceResource):
         ] = None,
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         """
 
     def load(self) -> None:
         """
-        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         """
 
     def put_alarm(
@@ -362,7 +367,7 @@ class Metric(Boto3ServiceResource):
         InsufficientDataActions: List[str] = None,
         Statistic: Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"] = None,
         ExtendedStatistic: str = None,
-        Dimensions: List[DimensionTypeDef] = None,
+        Dimensions: List["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: Literal[
             "Seconds",
@@ -397,22 +402,22 @@ class Metric(Boto3ServiceResource):
         Threshold: float = None,
         TreatMissingData: str = None,
         EvaluateLowSampleCountPercentile: str = None,
-        Metrics: List[MetricDataQueryTypeDef] = None,
-        Tags: List[TagTypeDef] = None,
+        Metrics: List["MetricDataQueryTypeDef"] = None,
+        Tags: List["TagTypeDef"] = None,
         ThresholdMetricId: str = None,
     ) -> _Alarm:
         """
-        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         """
 
     def put_data(self, MetricData: List[MetricDatumTypeDef]) -> None:
         """
-        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         """
 
     def reload(self) -> None:
         """
-        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         """
 
 
@@ -421,7 +426,7 @@ _Metric = Metric
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     """
 
     alarms: ServiceResourceAlarmsCollection
@@ -429,15 +434,15 @@ class CloudWatchServiceResource(Boto3ServiceResource):
 
     def Alarm(self, name: str) -> _Alarm:
         """
-        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         """
 
     def Metric(self, namespace: str, name: str) -> _Metric:
         """
-        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         """
