@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for cloudwatch service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudwatch import (
+
+    from mypy_boto3_cloudwatch import CloudWatchClient
+    from mypy_boto3_cloudwatch.waiter import (
         AlarmExistsWaiter,
         CompositeAlarmExistsWaiter,
     )
@@ -13,11 +17,13 @@ Usage::
 
     alarm_exists_waiter: AlarmExistsWaiter = client.get_waiter("alarm_exists")
     composite_alarm_exists_waiter: CompositeAlarmExistsWaiter = client.get_waiter("composite_alarm_exists")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import List, TYPE_CHECKING
+from typing import List
+
 from botocore.waiter import Waiter as Boto3Waiter
+
 from mypy_boto3_cloudwatch.type_defs import WaiterConfigTypeDef
 
 if sys.version_info >= (3, 8):
@@ -31,7 +37,7 @@ __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 class AlarmExistsWaiter(Boto3Waiter):
     """
-    [Waiter.AlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+    [Waiter.AlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
     """
 
     def wait(
@@ -48,13 +54,13 @@ class AlarmExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [AlarmExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
+        [AlarmExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
         """
 
 
 class CompositeAlarmExistsWaiter(Boto3Waiter):
     """
-    [Waiter.CompositeAlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+    [Waiter.CompositeAlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
     """
 
     def wait(
@@ -71,5 +77,5 @@ class CompositeAlarmExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [CompositeAlarmExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
+        [CompositeAlarmExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
         """
